'use strict';

function setupContentsRepeater(repeatertab, repeaterInfo, data) {
    const handler = (data) => {
        updateContentsRepeater(repeatertab, data);
    };

    noraapi.addEventHandler(
        "update_status_" + repeaterInfo.webSocketRoomId,
        handler
    );
}

function updateContentsRepeater(repeatertab, data) {
    logger.trace(
        "Update contents repeater.\n" +
        JSON.stringify(data)
    );

    repeatertab.empty();

    const repeaterContents =
        createContentsRepeater(repeatertab, data.webSocketRoomId);

    const isScopePrivate = String(data.scope).toLowerCase() === 'private';
    const isScopePublic = String(data.scope).toLowerCase() === 'public';
    const isScopUnknown = String(data.scope).toLowerCase() === 'unknown';

    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.repeater_callsign'))
        .text(data.repeaterCallsign);
    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.repeater_type'))
        .text(data.repeaterType);
    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.routing_service'))
        .text(data.routingService);
    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.linked_reflector'))
        .text(data.linkedReflectorCallsign);
    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.scope'))
        .text(data.scope)
        .removeClass('text-success text-warning text-danger')
        .addClass(
            (isScopePrivate ? 'text-success' : '') +
            (isScopePublic ? 'text-warning' : '') +
            (isScopUnknown ? 'text-danger' : '')
        );
    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.position'))
        .text('[Map]')
        .addClass('text-white')
        .attr(
            'href',
            'https://www.google.com/maps?q=' + data.latitude + ',' + data.longitude
        );
    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.location'))
        .text(data.description1);
    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.frequency'))
        .text(
            (Math.round(data.frequency / 10000) / 100) + 'MHz(Offset : ' +
            (Math.round(data.frequencyOffset / 10000) / 100) + 'MHz)'
        );
    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.agl'))
        .text(data.agl);
    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.description'))
        .text(data.description2);
    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.url'))
        .text(data.url).attr("href", data.url);
    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.allow_direct'))
        .text(data.allowDIRECT ? 'ON' : 'OFF');
    repeaterContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.auto_disconnect_reflector_g2'))
        .text(data.autoDisconnectFromReflectorOnTxToG2Route ? 'ON' : 'OFF');

}

function createContentsRepeater(repeatertab, functionID) {
    let repeaterContents =
        $(repeatertab).find(
            "[contents-id=" + selectorEscape(functionID) + "]"
        );
    if(!repeaterContents.exists()){
        logger.info("isEnableRepeaterReflectorLinkControl = " + isEnableRepeaterReflectorLinkControl);
        const repeaterContentsConfig =
        {
            "repeater_callsign_id" : functionID + '.repeater_callsign',
            "repeater_type_id" : functionID + '.repeater_type',
            "routing_service_id" : functionID + '.routing_service',
            "linked_reflector_id" : functionID + '.linked_reflector',
            "scope_id" : functionID + '.scope',
            "position_id" : functionID + '.position',
            "location_id" : functionID + '.location',
            "frequency_id" : functionID + '.frequency',
            "agl_id" : functionID + '.agl_id',
            "description_id" : functionID + '.description',
            "url_id" : functionID + '.url',
            "allow_direct_id" : functionID + '.allow_direct',
            "auto_disconnect_reflector_g2_id" : functionID + '.auto_disconnect_reflector_g2',

            "reflector_link_control_id" : functionID + '.reflector_link_control',
            "reflector_link_control_label_for" : functionID + '.reflector_link_control_reflector_callsign',
            "reflector_link_control_reflector_callsign_id" : functionID + '.reflector_link_control_reflector_callsign',
            "reflector_link_control_reflector_callsign_aria_descrided_by" : functionID + '.reflector_link_control_reflector_callsign_help',
            "reflector_link_control_reflector_callsign_help_id" : functionID + '.reflector_link_control_reflector_callsign_help',
            "reflector_link_control_link_id" : functionID + '.reflector_link_control_link',
            "reflector_link_control_unlink_id" : functionID + '.reflector_link_control_unlink',

            "reflector_link_control_selector_modal_id" : functionID + '.reflector_link_control_selector_modal',
            "reflector_link_control_selector_aria_labelledby" : functionID + '.reflector_link_control_selector_label',
            "reflector_link_control_selector_label_id" : functionID + '.reflector_link_control_selector_label'
        };
        if(!isEnableRepeaterReflectorLinkControl)
            repeaterContentsConfig.reflector_link_control_btn_link_enable = 'disabled';

        repeaterContents =
            repeatertab.loadTemplate($("#template_repeater"), repeaterContentsConfig);

        repeaterContents.find('#' + selectorEscape(functionID + '.reflector_link_control_link'))
        .on('click', () =>{
            logger.trace("Reflector control(link) clicked");

            const reflectorCallsign =
                repeaterContents
                    .find(
                        '#' +
                        selectorEscape(functionID + '.reflector_link_control_reflector_callsign')
                    ).val().toUpperCase();

            const repeaterInfo = findRepeaterInfoByRepeaterFunctionID(functionID);
            if(repeaterInfo && reflectorCallsign){
                noraapi.request(
                    'request_reflector_link_' + functionID,
                    'response_reflector_link_' + functionID,
                    {
                        'reflectorCallsign' : reflectorCallsign,
                        'repeaterCallsign' : repeaterInfo.repeaterCallsign
                    }
                ).then((data) =>{
                    logger.info(
                        "Reflector control function returned " +
                        (data.success ? "success" : "failed") + "."
                    );
                });
            }
        });

        repeaterContents.find('#' + selectorEscape(functionID + '.reflector_link_control_unlink'))
        .on('click', () =>{
            logger.trace("Reflector control(unlink) clicked");

            const repeaterInfo = findRepeaterInfoByRepeaterFunctionID(functionID);
            if(repeaterInfo){
                noraapi.request(
                    'request_reflector_unlink_' + functionID,
                    'response_reflector_unlink_' + functionID,
                    {
                        'repeaterCallsign' : repeaterInfo.repeaterCallsign
                    }
                ).then((data) =>{
                    logger.info(
                        "Reflector control function returned " +
                        (data.success ? "success" : "failed") + "."
                    );
                });
            }
        });
    }

    return repeaterContents;
}